==> welltested-2.2.0.tar.gz: lib/generators/integration_generator.dart <==
import 'package:analyzer/dart/analysis/analysis_context_collection.dart';
import 'package:azure_application_insights/azure_application_insights.dart';
import 'package:welltested/src/executors/ast_elm_executor.dart';
import 'package:welltested/src/executors/fixer_executor.dart';
import 'package:welltested/src/executors/integration_executor.dart';
import 'package:welltested/src/executors/writer_executor.dart';
import 'package:welltested/src/models/test_request/integration/helper_action.dart';
import 'package:welltested/src/models/test_request/integration/integration_test_request.dart';
import 'package:welltested/src/models/test_run_info.dart';
import 'package:welltested/src/repositories/dart_server_repository.dart';
import 'package:welltested/src/repositories/generations_repository.dart';
import 'package:welltested/src/repositories/writer_repository.dart';
import 'package:welltested/src/utilities/agent/integration_append_agent.dart';
import 'package:welltested/src/utilities/path_utils.dart';
import 'package:welltested/src/utilities/telemetry_client.dart';

import '../src/models/pubspec_data.dart';
import '../src/models/test_request/integration/integration_test_input.dart';
import '../src/utilities/logging.dart';

class IntegrationGenerator {
  IntegrationGenerator({required this.dartServerRepository});
  final DartServerRepository dartServerRepository;
  late final GenerationRepository generationRepository = GenerationRepository();
  late final WriterRepository writerRepository;

  ///Executors
  late final FixerExecutor fixerExecutor;
  late final AstElementExecutor astElementExecutor;
  late final IntegrationExecutor unitTestExecutor;
  late final WriterExecutor writerExecutor;
  late final IntegrationExecutor integrationExecutor = IntegrationExecutor();

  void init() {
    writerRepository = WriterRepository();
    fixerExecutor = FixerExecutor(dartServerRepository.server);

    writerExecutor =
        WriterExecutor(writerRepository, dartServerRepository, fixerExecutor);
  }

  Future<void> generateForFlow(
      {required IntegrationTestInput testInput,
      required List<IntegrationTestInput> allTests,
      required int index,
      required PubspecData pubspecData,
      required AnalysisContextCollection collection,
      required TestRunInfo testRunInfo}) async {
    final testName =
        '${testInput.moduleName} -> ${index}. ${(testInput.testFlows[index]).substring(0, 9)}';
    try {
      wtLog.startSpinner("Generating Test for ${testName}...");
      testRunInfo.pushFunctionInQueue(testName);
      IntegrationRequestData integrationRequestData =
          await IntegrationExecutor().prepareRequest(
        testInput,
        allTests,
        index,
        pubspecData,
      );

      final response = await generationRepository
          .buildIntegrationTests(integrationRequestData);
      final file =
          PathUtils.correspondingIntegrationTestFile(testInput.moduleName);
      final integrationTest = response['integration_test'] as String;
      final List<HelperAction> helper_actions = (response['actions'] as List)
          .map((e) => HelperAction(
              filePath: e['file_path'],
              kind: 'static', //TODO
              className: e['class_name'],
              methodName: e['method_name'],
              method: e['method']))
          .toList();
      final integrationAppendAgent = IntegrationAppendAgent(writerExecutor);
      for (final action in helper_actions) {
        await integrationAppendAgent.appendMethod(
          action,
        );
      }
      await integrationAppendAgent.appendNewTest(
          existingTestFile: file,
          incomingTest: integrationTest,
          currentFlow: testInput.testFlows[index]);
      testRunInfo.incrementFromAction(TestGenerationStatus.create, testName);
    } catch (e, stackTrace) {
      wtTelemetry.trackError(
          severity: Severity.error, error: e, stackTrace: stackTrace);
      wtLog.warning(
          "Error generating integration tests: Module: ${testInput.moduleName} TestFlow: ${testInput.testFlows[index]}");
      wtLog.log('Cause: ${e.toString()}');
      testRunInfo.incrementFromAction(TestGenerationStatus.failed, testName);
    }
  }
}

==> welltested-2.2.2.tar.gz: lib/generators/integration_generator.dart <==
import 'package:analyzer/dart/analysis/analysis_context_collection.dart';
import 'package:azure_application_insights/azure_application_insights.dart';
import 'package:welltested/src/executors/ast_elm_executor.dart';
import 'package:welltested/src/executors/fixer_executor.dart';
import 'package:welltested/src/executors/integration_executor.dart';
import 'package:welltested/src/executors/writer_executor.dart';
import 'package:welltested/src/models/test_request/integration/helper_action.dart';
import 'package:welltested/src/models/test_request/integration/integration_test_request.dart';
import 'package:welltested/src/models/test_run_info.dart';
import 'package:welltested/src/repositories/dart_server_repository.dart';
import 'package:welltested/src/repositories/generations_repository.dart';
import 'package:welltested/src/repositories/writer_repository.dart';
import 'package:welltested/src/utilities/agent/integration_append_agent.dart';
import 'package:welltested/src/utilities/path_utils.dart';
import 'package:welltested/src/utilities/telemetry_client.dart';

import '../src/models/pubspec_data.dart';
import '../src/models/test_request/integration/integration_test_input.dart';
import '../src/utilities/logging.dart';

class IntegrationGenerator {
  IntegrationGenerator({required this.dartServerRepository});
  final DartServerRepository dartServerRepository;
  late final GenerationRepository generationRepository = GenerationRepository();
  late final WriterRepository writerRepository;

  ///Executors
  late final FixerExecutor fixerExecutor;
  late final AstElementExecutor astElementExecutor;
  late final IntegrationExecutor unitTestExecutor;
  late final WriterExecutor writerExecutor;
  late final IntegrationExecutor integrationExecutor = IntegrationExecutor();

  void init() {
    writerRepository = WriterRepository();
    fixerExecutor = FixerExecutor(dartServerRepository.server);

    writerExecutor =
        WriterExecutor(writerRepository, dartServerRepository, fixerExecutor);
  }

  Future<void> generateForFlow(
      {required IntegrationTestInput testInput,
      required List<IntegrationTestInput> allTests,
      required int index,
      required PubspecData pubspecData,
      required AnalysisContextCollection collection,
      required TestRunInfo testRunInfo}) async {
    final testName =
        '${testInput.moduleName} -> ${index + 1}. ${(testInput.testFlows[index])}';
    try {
      wtLog.startSpinner("Generating Test for ${testName}...");
      testRunInfo.pushFunctionInQueue(testName);
      IntegrationRequestData integrationRequestData =
          await IntegrationExecutor().prepareRequest(
        testInput,
        allTests,
        index,
        pubspecData,
      );

      final response = await generationRepository
          .buildIntegrationTests(integrationRequestData);
      final file =
          PathUtils.correspondingIntegrationTestFile(testInput.moduleName);
      final integrationTest = response['integration_test'] as String;
      final List<HelperAction> helper_actions = (response['actions'] as List)
          .map((e) => HelperAction(
              filePath: e['file_path'],
              kind: 'static', //TODO
              className: e['class_name'],
              methodName: e['method_name'],
              method: e['method']))
          .toList();
      final integrationAppendAgent = IntegrationAppendAgent(writerExecutor);
      for (final action in helper_actions) {
        await integrationAppendAgent.appendMethod(
          action,
        );
      }
      await integrationAppendAgent.appendNewTest(
          existingTestFile: file,
          incomingTest: integrationTest,
          currentFlow: testInput.testFlows[index]);
      testRunInfo.incrementFromAction(TestGenerationStatus.create, testName);
    } catch (e, stackTrace) {
      wtTelemetry.trackError(
          severity: Severity.error, error: e, stackTrace: stackTrace);
      wtLog.warning(
          "Error generating integration tests: Module: ${testInput.moduleName} | TestFlow: ${testInput.testFlows[index]}");
      wtLog.log('Cause: ${e.toString()}');
      testRunInfo.incrementFromAction(TestGenerationStatus.failed, testName);
    }
  }
}
